# Test ToC

## Works as intended

This file tests that headers work as intended.

### More on the ToC

The ToC is the list of all headers in the file, and it should be possible to include it in any part of it. Like here

- Test ToC
  - Works as intended
    - More on the ToC
  - Conclusion

## Conclusion

This is another example, the ToC here should be the same as the ToC above.

- Test ToC
  - Works as intended
    - More on the ToC
  - Conclusion